rayoptics package
=================

.. automodule:: rayoptics
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   rayoptics.codev
   rayoptics.elem
   rayoptics.gui
   rayoptics.mpl
   rayoptics.oprops
   rayoptics.optical
   rayoptics.parax
   rayoptics.qtgui
   rayoptics.raytr
   rayoptics.seq
   rayoptics.util
   rayoptics.zemax

Submodules
----------

rayoptics.environment module
----------------------------

.. automodule:: rayoptics.environment
   :members:
   :undoc-members:
   :show-inheritance:

